"""Package for supporting tapo-branded cameras."""

from .smartcamchild import SmartCamChild
from .smartcamdevice import SmartCamDevice

__all__ = ["SmartCamDevice", "SmartCamChild"]
